stac.parametric_tests.bonferroni_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.parametric_tests.bonferroni_test

`stac.parametric_tests.` `bonferroni_test`(pivots, n)

  Performs a Bonferroni-Dunn post-hoc test using the pivot quantities obtained by an ANOVA test.

  Parameters: | pivots : dictionary_like A dictionary with format ‘groupname’:’pivotal quantity’ n : int Number of samples per group
  Returns: | Comparions : array-like Strings identifier of each comparison with format ‘group_i vs group_j’ T-values: array-like The computed T-value statistic for each comparison. p-values: array-like The associated p-value from the T-distribution wich depends on the index of the comparison Adjusted p-values: array-like The associated adjusted p-values wich can be compared with a significance level

  References

  D.J. Sheskin, Handbook of parametric and nonparametric statistical procedures. crc Press, 2003, Test 21b: The Bonferroni-Dunn test

### Navigation

- index
- STAC Release Candidate documentation »